import os
from datetime import datetime
import json 
from typing import Any

def saveFile(pushName: str, gatherTasks: Any) -> None:
    if not os.path.isdir(f'{pushName}'):
        os.mkdir(f'{pushName}')

    with open(f'{pushName}/{datetime.now()}data.json', 'w', encoding='utf-8') as f:
        json.dump(gatherTasks, f, ensure_ascii=False, indent=4)
        print('end')
        
if __name__ == '__main__':
    pass


import json
import asyncio
from typing import TypedDict, List, Dict, Union, Awaitable, Any
from aiogram import  types
from tg_bot_sender.conf import TELEGRAM_API_URL

class Button(TypedDict):
    buttonTitle: str
    buttonUrl: str
    
class Data(TypedDict):
    photo: str
    text: str
    buttons: List[Button]
    
async def sendMessage(session, user: int, pushData: Data, token: str) -> Awaitable[Any]:
    url: str = f"{TELEGRAM_API_URL}{token}/"
    data: Dict[str, Union[str, int]] = {
        "chat_id": user,
        'parse_mode': types.ParseMode.HTML,
    }
 
    if pushData.get('photo', None):
        data['caption'] = pushData.get('caption','')
        data['photo'] = pushData.get('photo', '')
        url += 'sendPhoto'
    else: 
        data['text'] = pushData.get('text','')
        url += 'sendMessage'

    if pushData.get('buttons',None):
        res = { "inline_keyboard": [] }
        for button in pushData.get('buttons',None):
            res.get('inline_keyboard').append([{
                "text": button["buttonTitle"], 
                "url": button["buttonUrl"],
            }])
       
        data['reply_markup'] = json.dumps(res)


    async with session.post(url, data=data, ssl=False) as response:
        await asyncio.sleep(1)
        return await response.json()
    
if __name__ == '__main__':
    pass


import time
import asyncio
import aiohttp
from typing import List, TypedDict, Awaitable
from tg_bot_sender.saveFile import saveFile
from tg_bot_sender.sendMessage import sendMessage, Data
from tg_bot_sender.conf import DIVIDER_AMOUNT

class Response(TypedDict):
    amount: str
class TelegramSender():
    def __init__(self, token, logs = False):
        self.token = token
        self.loop = asyncio.get_event_loop()
        self.logs = logs
        
    def groupUser(self, idsArray) -> List[List[int]]:
        return [idsArray[d:d+DIVIDER_AMOUNT] for d in range(0, len(idsArray), DIVIDER_AMOUNT)]
    
    def saveExecuter(self, gatherTasks) -> None:
        if self.logs:
            return saveFile(str(round(time.time())), gatherTasks)
    
    async def sendFromIds(self, idsArray: List[int], data: Data) -> Awaitable[Response]:
        slicedIdArray = self.groupUser(idsArray)
        tasks = []
        for idArray in slicedIdArray:
            async with aiohttp.ClientSession(loop=self.loop,connector=aiohttp.TCPConnector(ssl=False),trust_env=True) as session:
                print('LOG: start sending')
                tasks = [
                    asyncio.create_task(
                        sendMessage(session, userId, data, self.token)) for userId in idArray
                ]
                gatherTasks = await asyncio.gather(*tasks)
                self.saveExecuter(gatherTasks)
                print('LOG: end sending')
                
        return Response(amount=len(gatherTasks))

    async def sendFromId(self, id: int, data: Data) -> Awaitable[Response]:
        async with aiohttp.ClientSession(loop=self.loop,connector=aiohttp.TCPConnector(ssl=False),trust_env=True) as session:
            print('LOG: start sending')
            data = await asyncio.create_task(sendMessage(session, id, data, self.token))
            self.saveExecuter(data)
            print('LOG: end sending')
            return Response(amount=1)
            


if __name__=='__main__':
    loop=asyncio.get_event_loop()
    tg = TelegramSender('*')
    
    startTime = time.time()
    data = loop.run_until_complete(tg.sendFromId('*', Data(text='Hello')))
    d = loop.run_until_complete(tg.sendFromIds(['*', '*', '*'], Data(text='Hello')))
    print(f'LOG: time {time.time() - startTime}')



from setuptools import setup

setup(name='tg_bot_sender',
      version='0.5',
      description='This lib for sending message to tg bots',
      packages=['tg_bot_sender'],
      author_email='poznkirill3@gmail.com',
      long_description="""
      [Link to the documentation](https://magnificent-maamoul-2f7a55.netlify.app/)
# Python
How to install ?
```pip
pip install tg-bot-sender
```
## Imports 
```python
from tg_bot_sender import Data, TelegramSender
```
## Getting started
The logs parameter indicates that logs are saved in json format
```python
tg = TelegramSender(telegramToken, logs = False)
```
Response structure
```json
{ "amount": 0 } // number of messages sent
```
## Options for sending messages
#### sendFromIds - sending to users
```python
tg.sendFromIds([...telegramUserIds], Data(
    text = 'Hello',
    photo = 'Photo link',
    buttons = [{
        buttonTitle: 'Hello',
        buttonUrl: 'https://google.com'
    }]
))
```
#### sendFromId - sending to the user
```python
tg.sendFromIds(telegramUserId, Data(
    text = 'Hello',
    photo = 'Photo link',
    buttons = [{
        buttonTitle: 'Hello',
        buttonUrl: 'https://google.com'
    }]
))
```

      """,
      long_description_content_type='text/markdown',
      zip_safe=False)